#
# spec file for package aws-checksums
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define library_version 1.0.0
%define library_soversion 1
Name:           aws-checksums
Version:        0.1.18
Release:        1.1
Summary:        Checksums package for AWS SDK for C
License:        Apache-2.0
Group:          Development/Libraries/C and C++
URL:            https://github.com/awslabs/aws-checksums
Source0:        https://github.com/awslabs/%{name}/archive/v%{version}.tar.gz
Patch0:         ac_fix-cmake-modules-path.patch
Patch1:         ac_re-add-so-version.patch
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  ninja
BuildRequires:  cmake(aws-c-common)

%description
Core c99 package for AWS SDK for C. Includes cross-platform primitives,
configuration, data structures, and error handling.

%package -n lib%{name}%{library_soversion}
Summary:        Shared library files for aws-checksums library
Group:          Development/Libraries/C and C++

%description -n lib%{name}%{library_soversion}
Cross-Platform hardware-accelerated CRC32c and CRC32 with fallback to
efficient software implementations. C interface with language bindings
for each of the AWS SDKs.

This package contains the dynamically linked library.

%package -n lib%{name}-devel
Summary:        Development files for aws-checksums library
Group:          Development/Libraries/C and C++
Requires:       lib%{name}%{library_soversion} = %{version}

%description -n lib%{name}-devel
Core c99 package for AWS SDK for C. Includes cross-platform primitives,
configuration, data structures, and error handling.

This package contains the development files.

%prep
%autosetup -p1

%build
%define __builder ninja
%cmake \
    -DCMAKE_BUILD_TYPE=Release
%make_jobs

%check
export LD_LIBRARY_PATH=%{_builddir}/%{name}-%{version}/build
%ctest

%install
%cmake_install

%post -n lib%{name}%{library_soversion} -p /sbin/ldconfig
%postun -n lib%{name}%{library_soversion} -p /sbin/ldconfig

%files -n lib%{name}%{library_soversion}
%doc README.md
%license LICENSE
%{_libdir}/*.so.%{library_soversion}
%{_libdir}/*.so.%{library_version}

%files -n lib%{name}-devel
%{_libdir}/cmake/%{name}/
%{_libdir}/*.so
%{_includedir}/*

%changelog
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Mon Feb 19 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.1.18
  * Added workflow for handling answerable discussions by @yasminetalby in (#75)
  * Remove unused source/arm/asm directory include by @waahm7 in (#78)
  * BUILDER_VERSION: v0.9.55 by @graebm in (#80)
* Mon Jul 17 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.1.17
  * Refactor CPU_EXTENSIONS logic for MSVC with Clang by @waahm7 in (#69)
* Wed Jun  7 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.1.16
  * Add Github templates and bots by @jmklix in (#64)
  * Fix use of inline ASM labels by @jamesbornholt in (#65)
* Tue May 16 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.1.15
  * Add to .gitignore by @graebm in (#62)
  * Fix warnings in public headers by @waahm7 in (#63)
* Wed Jan 18 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.1.14
  * Add AppVerifier to CI by @TwistedTwigleg in (#58)
  * Update CI to fix downstream build by @waahm7 in (#59)
  * Fixed gcc and clang constraint error due to improper
    input operands and clobbers via suggestion from @topperc
    by @JonathanHenson in (#57)
* Thu Sep  1 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.1.13
  + Allow mix of static and shared libs
  * Load cmake target fallback by @TingDaoK in (#56)
- Use cmake() macro in BuildRequires
* Mon Oct 11 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.1.12
  + Support new build flag: USE_CPU_EXTENSIONS
  * If -DUSE_CPU_EXTENSIONS=OFF then do not use function implementations
    that are optimized for specific CPU architectures, only use the generic
    implementation
* Mon Feb 15 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.1.11
  + Improved ARM support
  * Updated feature test compilation flags to properly
    detect/fail Cortex features
* Thu Nov 19 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.1.10
  + Removed UNSTABLE from SONAME
  * Removed 0unstable from SOVERSION (#36)
- Add patch to re-add SOVERSION to library
  + ac_re-add-so-version.patch
- Bump library_soversion to 1
* Tue Aug 25 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.1.9
  + Updates cmake files to use the local project name,
    fixing consumers using this as a submodule
- Add missing %%{library_soversion} to Requires for -devel package
* Fri Aug 14 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.1.8
  + Refactor to run on aws-c-common's cpuid checks and cmake macros. (#31)
  + Add support for using Arm CRC instructions (#31)
  + Fix exported symbols according to changes in aws-c-common. (#32)
- Add libaws-c-common-devel to BuildRequires
- Append library ABI version to runtime package name
- Fix installation path for aws-checksums-targets.cmake
  in patch to fix cmake modules path in CMakeLists.txt
  + ac_fix-cmake-modules-path.patch
* Tue Jun 16 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.1.7
  + Fix duplicate symbols in gcc < 4.4
- from version 0.1.6
  + Make sure clang builds use the hw optimized code, disable the
    asm on assemblers that don't know of clmul's existence.
* Mon Oct 28 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.1.5
  + Android Build Fix
  * This release fixes conflicting symbols when building for Android.
* Thu Oct  3 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.1.4
  + Fixed mixed static/shared builds
  * Added support for shared/static lib builds in the same build closure
* Tue Jul 16 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.1.3
  + Fix MSVC ARM Build
  * It just forwards to the SW implementation, but it's better than nothing.
* Wed Apr 10 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Move cmake files to correct installation path
* Mon Feb 11 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Initial build
  + Version 0.1.2
